function [A] = gen_A_mat_clustered(n,m,seed)
%
% A simple routine to generates a matrix with two clusters of eigenvalues one large and another small 
%
% Written by:
% -- 
% John L. Weatherwax                2007-04-02
% 
% email: wax@alum.mit.edu
% 
% Please send comments and especially bug reports to the
% above email address.
% 
%-----

if( nargin==3 )
  rand('seed',seed);
end

nmm = n-m; 

Lambda1 = 1  + rand(nmm,1); % the "small" eigenvalues are clustered between [1,2] "around 1.5" 
Lambda2 = 10 + rand(m,1); % the "large" eigenvalues are clustered between [10,11] i.e. "around 10.5"

Lambda  = [ Lambda1; Lambda2 ];
Lambda  = Lambda( randperm( length(Lambda) ) ); % randomized the order of the eigenvalues 
Lambda  = diag( Lambda ); 

X      = rand(n,n); % generate a random matrix 
[S,R]  = qr(X); % get an orthogonal matrix "S" from X 

% generate A with the specified eigenvalue distribution 
% ( a similiarity transformation of the matrix Lambda ) : 
A = S * Lambda * (S');





