% 
% Written by:
% -- 
% John L. Weatherwax                2006-08-28
% 
% email: wax@alum.mit.edu
% 
% Please send comments and especially bug reports to the
% above email address.
% 
%-----

clc; close all; clear; 

% simple example of how to call this code: 
n  = 5; 
A  = hilb( n ); 
b  = ones(n,1); 
x0 = zeros(n,1); 

[x,niter,rtr] = cgsolve( A, b, x0, 100, 1.e-6 ); 
x_truth   = invhilb(n) * b;
fprintf('In the example case how accurate are we= %10.6g\n', norm( x-x_truth ) ); % lets see how well we did 

% Lets do the suggested grid of increasingly larger n values: 
%
allNs     = [ 5, 8, 12, 20 ];
allNIters = [];
for n=allNs
  A  = hilb( n ); 
  b  = ones(n,1); 
  x0 = zeros(n,1); 
  
  [x,niter,rtr] = cgsolve( A, b, x0, 100000, 1.e-6 ); % pick the number of iterations so large that we never hit that limit 
  allNIters = [ allNIters, niter ];
end

plot( allNs, allNIters, '-o' ); 
xlabel('size of Hilbert matrix (n)'); ylabel('number of iterations required to reduced the error to 1.e-6'); 
grid on; 

saveas( gcf, '../../WriteUp/Graphics/Chapter5/chap_5_prob_1_n_vs_nIters.eps', 'psc2' );
